import Vue from 'vue'
import Router from 'vue-router'

Vue.use(Router)

/* Layout */
import Layout from '@/layout'

/**
 * Note: sub-menu only appear when route children.length >= 1
 * Detail see: https://panjiachen.github.io/vue-element-admin-site/guide/essentials/router-and-nav.html
 *
 * hidden: true                   if set true, item will not show in the sidebar(default is false)
 * alwaysShow: true               if set true, will always show the root menu
 *                                if not set alwaysShow, when item has more than one children route,
 *                                it will becomes nested mode, otherwise not show the root menu
 * redirect: noRedirect           if set noRedirect will no redirect in the breadcrumb
 * name:'router-name'             the name is used by <keep-alive> (must set!!!)
 * meta : {
    roles: ['admin','editor']    control the page roles (you can set multiple roles)
    title: 'title'               the name show in sidebar and breadcrumb (recommend set)
    icon: 'svg-name'/'el-icon-x' the icon show in the sidebar
    breadcrumb: false            if set false, the item will hidden in breadcrumb(default is true)
    activeMenu: '/example/list'  if set path, the sidebar will highlight the path you set
  }
 */

/**
 * constantRoutes
 * a base page that does not have permission requirements
 * all roles can be accessed
 */
export const constantRoutes = [
  {
    path: '/login',
    component: () => import('@/views/login/index'),
    hidden: true
  },

  {
    path: '/404',
    component: () => import('@/views/404'),
    hidden: true
  },

  {
    path: '/',
    component: Layout,
    redirect: '/dashboard',
    children: [{
      path: 'dashboard',
      name: 'Dashboard',
      component: () => import('@/views/dashboard/index'),
      meta: {title: 'Dashboard', icon: 'dashboard'}
    }]
  },
  {
    path: '/meeting',
    name: 'Meeting',
    component:()=>import('@/views/meeting/meeting')
  },
  {
    path:'/weekly',
    name: 'Weekly',
    component:()=>import('@/views/meeting/weekly')
  },
  {
    path: '/weeklyRecords',
    name: 'WeeklyRecords',
    component:()=>import('@/views/meeting/weeklyRecords')
  },
  {
    path: '/enforceflow',
    name: 'EnforceFlow',
    component:()=>import('@/views/enforceflow/enforceflow')
  },
  {
    path: '/enforceflowdetail',
    name: 'EnforceFlowDetail',
    component:()=>import('@/views/enforceflow/enforceflowdetail')
  },

  // {
  //   path: '/system',
  //   component: Layout,
  //   redirect: '/system/menu',
  //   name: '系统管理',
  //   meta: {title: 'Example', icon: 'el-icon-s-help'},
  //   children: [
  //     {
  //       path: 'menu',
  //       name: '菜单管理',
  //       component: () => import('@/views/system/menu'),
  //       meta: {title: '菜单管理', icon: 'table'}
  //     },
  //     {
  //       path: 'dept',
  //       name: '部门管理',
  //       component: () => import('@/views/system/dept'),
  //       meta: {title: '部门管理', icon: 'task'}
  //     },
  //     {
  //       path: 'role',
  //       name: '角色管理',
  //       component: () => import('@/views/system/role'),
  //       meta: {title: '角色管理', icon: 'task'}
  //     },
  //     {
  //       path: 'user',
  //       name: '员工管理',
  //       component: () => import('@/views/system/user'),
  //       meta: {title: '员工管理', icon: 'task'}
  //     }
  //   ]
  // },

  // 404 page must be placed at the end !!!
  {path: '*', redirect: '/404', hidden: true}
]

// 动态路由，基于用户权限动态去加载
export const dynamicRoutes = []

// 防止连续点击多次路由报错
let routerPush = Router.prototype.push;
let routerReplace = Router.prototype.replace;
// push
Router.prototype.push = function push(location) {
  return routerPush.call(this, location).catch(err => err)
}
// replace
Router.prototype.replace = function push(location) {
  return routerReplace.call(this, location).catch(err => err)
}

export default new Router({
  base: process.env.VUE_APP_CONTEXT_PATH,
  mode: 'history', // 去掉url中的#
  scrollBehavior: () => ({ y: 0 }),
  routes: constantRoutes
})

// const createRouter = () => new Router({
//   // mode: 'history', // require service support
//   scrollBehavior: () => ({y: 0}),
//   routes: constantRoutes
// })
//
// const router = createRouter()
//
// // Detail see: https://github.com/vuejs/vue-router/issues/1234#issuecomment-357941465
// export function resetRouter() {
//   const newRouter = createRouter()
//   router.matcher = newRouter.matcher // reset router
// }
//
// export default router
